interface RecipientHeader {
    alg: string;
    iv: string;
    tag: string;
    epk?: Record<string, any>;
    kid?: string;
}
export interface Recipient {
    header: RecipientHeader;
    encrypted_key: string;
}
export interface JWE {
    protected: string;
    iv: string;
    ciphertext: string;
    tag: string;
    aad?: string;
    recipients?: Recipient[];
}
export interface EncryptionResult {
    ciphertext: Uint8Array;
    tag: Uint8Array;
    iv: Uint8Array;
    protectedHeader?: string;
    recipient?: Recipient;
    cek?: Uint8Array;
}
export interface Encrypter {
    alg: string;
    enc: string;
    encrypt: (cleartext: Uint8Array, protectedHeader: Record<string, any>, aad?: Uint8Array) => Promise<EncryptionResult>;
    encryptCek?: (cek: Uint8Array) => Promise<Recipient>;
}
export interface Decrypter {
    alg: string;
    enc: string;
    decrypt: (sealed: Uint8Array, iv: Uint8Array, aad?: Uint8Array, recipient?: Record<string, any>) => Promise<Uint8Array>;
}
export declare function createJWE(cleartext: Uint8Array, encrypters: Encrypter[], protectedHeader?: {}, aad?: Uint8Array): Promise<JWE>;
export declare function decryptJWE(jwe: JWE, decrypter: Decrypter): Promise<Uint8Array>;
export {};
