"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RSASignerAlg = void 0;
const tslib_1 = require("tslib");
/**
 * RSA Signer
 * @returns A SignerAlgorithm instance
 */
function RSASignerAlg() {
    return function sign(payload, signer) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let signature;
            try {
                signature = yield signer(payload);
            }
            catch (e) {
                console.log(e);
            }
            if (signature) {
                return signature;
            }
            else {
                throw new Error('expected a signer function that returns a string instead of signature object');
            }
        });
    };
}
exports.RSASignerAlg = RSASignerAlg;
const algorithms = {
    RS256: RSASignerAlg()
};
function SignerAlg(alg) {
    const impl = algorithms[alg];
    if (!impl)
        throw new Error(`Unsupported algorithm ${alg}`);
    return impl;
}
exports.default = SignerAlg;
//# sourceMappingURL=SignerAlgorithm.js.map