import { Signer } from '../JWT';
/**
 *  Creates a configured signer function for signing data using the RSA algorithm.
 *
 *  The signing function itself takes the data as a `Uint8Array` or `string` and returns a `base64Url`-encoded signature
 *
 *  @example
 *  ```typescript
 *  const sign: Signer = RSASigner(process.env.PEM)
 *  const signature: string = await sign(data)
 *  ```
 *
 *  @param    {String}    pem         a PEM
 *  @return   {Function}              a configured signer function `(data: string | Uint8Array): Promise<string>`
 */
export declare function RSASigner(pem: string | Uint8Array): Signer;
